@@ -1,5 +1,5 @@
 import torch
-from aimped.nlp.tokenizer import SentenceTokenizer, WordTokenizer
+from aimped.nlp.tokenizer import sentence_tokenizer, word_tokenizer
 from transformers import AutoTokenizer, AutoModelForTokenClassification
 from aimped.nlp.pipeline import Pipeline
 
@@ -12,8 +12,8 @@ device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
 
 # load data
 text = open("data.txt", "r").read()
-sentences = SentenceTokenizer(text, "english")
-sents_tokens_list = WordTokenizer(sentences)
+sentences = sentence_tokenizer(text, "english")
+sents_tokens_list = word_tokenizer(sentences)
 white_label_list = ['PATIENT', 'ORGANIZATION', 'SSN', 'SEX', 'DOCTOR', 'HOSPITAL', 'AGE', 'MEDICALRECORD', 'ZIP',
                     'STREET', 'EMAIL', 'DATE', 'ID', 'CITY', 'COUNTRY', 'PROFESSION']
 # print(sents_tokens_list)
